# pareto-front

Welcome to the repository for the pareto-front project!

## Quickstart

<!-- uncomment if relevant
### Install from PyPI

```python
pip install pareto-front
```
-->
### Install from source

```bash
pip install git@github.com:ericmjl/pareto-front
```

### Build and preview docs

```bash
mkdocs serve
```

## Why this project exists

Place your reasons here for why this project exists.

What benefits does this project give to users?
